@@ -1,14 +1,10 @@
 from bibtutils.version import __version__
-__all__ = [
-    'storage',
-    'bigquery',
-    'secrets',
-    'pubsub'
-]
+
+__all__ = ["storage", "bigquery", "secrets", "pubsub"]
 
 from bibtutils.gcp import storage
 from bibtutils.gcp import secrets
 from bibtutils.gcp import pubsub
 from bibtutils.gcp import bigquery
 
-'''GCP-related functionality often used by BIBT.'''
\ No newline at end of file
+"""GCP-related functionality often used by BIBT."""
