@@ -1,10 +1,8 @@
 from bibtutils.version import __version__
-__all__ = [
-    'error',
-    'message'
-]
+
+__all__ = ["error", "message"]
 
 from bibtutils.slack import error
 from bibtutils.slack import message
 
-'''Slack-related functionality for BIBT.'''
\ No newline at end of file
+"""Slack-related functionality for BIBT."""
